@@ -1,21 +1,46 @@
+'''
+bibtutils.gcp.bigquery
+~~~~~~~~~~~~~~~~~~~~~~
+
+Functionality making use of GCP's BigQuery.
+
+'''
+
 from google.cloud import bigquery
 import logging
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
 
-def upload_gcs_json(bucket_name:str, blob_name:str, bq_project:str, dataset:str, table:str, append=True, ignore_unknown=True) -> None:
+def upload_gcs_json(bucket_name, blob_name, bq_project, dataset, table, 
+        append=True, ignore_unknown=True):
     '''
     Uploads a GCS blob in JSON NLD format to the specified table in BQ.
-    Executing account must have both read permissions on the bucket/blob and edit permissions on the dataset, in addition to the IAM bigquery jobs user role in the project.
+    Executing account must have both read permissions on the bucket/blob 
+    and edit permissions on the dataset, in addition to the IAM bigquery 
+    jobs user role in the project.
 
-    Args:
-        bucket_name (str): the bucket hosting the specified blob.
-        blob_name (str): the blob to upload to BQ. must be in JSON NLD format.
-        bq_project (str): the project hosting the specified BQ dataset.
-        dataset (str): the dataset hosting the specified table.
-        table (str): the table to which to upload the blob.
-        append (bool, optional): if true, will append to table. if false, will overwrite. Defaults to True.
-        ignore_unknown (bool, optional): if true, will ignore values not reflected in table schema while uploading. Defaults to True.
+    :type bucket_name: `str`
+    :param bucket_name: the bucket hosting the specified blob.
+
+    :type blob_name: `str`
+    :param blob_name: the blob to upload to BQ. must be in JSON NLD format.
+
+    :type bq_project: `str`
+    :param bq_project: the project hosting the specified BQ dataset.
+
+    :type dataset: `str`
+    :param dataset: the dataset hosting the specified table.
+
+    :type table: `str`
+    :param table: the table to which to upload the blob.
+
+    :type append: `bool`
+    :param append: (Optional) if true, will append to table. 
+        if false, will overwrite. Defaults to ``True``.
+    
+    :type ignore_unknown: `bool`
+    :param ignore_unknown: (Optional) if true, will ignore values not 
+        reflected in table schema while uploading. Defaults to ``True``.
     '''
     # TODO: allow schema update options? https://googleapis.dev/python/bigquery/latest/generated/google.cloud.bigquery.job.SchemaUpdateOption.html#google.cloud.bigquery.job.SchemaUpdateOption
 
@@ -41,16 +66,18 @@ def upload_gcs_json(bucket_name:str, blob_name:str, bq_project:str, dataset:str,
     return
 
 
-def query(query:str) -> list:
+def query(query):
     '''
-    Sends the user-supplied query to BQ and returns the result as a list of dicts.
-    The account running the query must have Job Create permissions in the GCP Project and at least Data Viewer on the target dataset.
+    Sends the user-supplied query to BQ and returns the result 
+    as a list of dicts. The account running the query must have 
+    Job Create permissions in the GCP Project and at least 
+    Data Viewer on the target dataset.
 
-    Args:
-        query (str): A full BQ query (i.e. 'select * from `x.y.z` where a=b')
+    :type query: `str`
+    :param query: a full BQ query (e.g. ``'select * from `x.y.z` where a=b'``)
 
-    Returns:
-        list: A list of dicts, one row in the result table per dict.
+    :rtype: `list`
+    :returns: a list of dicts, one row in the result table per dict.
     '''
     logging.debug(f'Sending query: {query}')
     bq_client = bigquery.Client()
